@@ -420,6 +420,12 @@ def _check_pooling_compatibility(model, pool_index):
     layer_pool = model.layers[pool_index]
     prev_layer = model.layers[pool_index - 1]
 
+    # Raise error if pooling layer is the first layer of the sequence/branch
+    if pool_index == 0:
+        raise RuntimeError(f"Pooling layer '{layer_pool.name}' cannot be the "
+                           "first layer of a model or sequence. It must be "
+                           "placed after a convolutional layer.")
+
     # Raise error if GlobalAvgPool2D is placed after the activation
     if type(prev_layer) not in conv_neural_layers:
         raise RuntimeError(f"Pooling layer {layer_pool.name} must be placed "
