@@ -283,6 +283,7 @@ def sequential_convert_to_akida_layers(model,
         if isinstance(layer, quantized_neural_layers):
             layer_neural = layer
             layer_ak_type, params = _parse_neural_layer(layer)
+            _check_weight_bitwidth(params['weights_bits'], layer.name)
         elif isinstance(layer, layers.MaxPool2D):
             _parse_max_pooling(layer, params)
         elif isinstance(layer, layers.GlobalAvgPool2D):
@@ -378,13 +379,12 @@ def _handle_input_conv_layer(model, input_scaling):
 
 
 def _check_activation_bitwidth(layer):
-    """Checks that activation bitwidth is an integer between 1 and 4.
+    """Checks that activation bitwidth is either 1, 2 or 4.
     """
 
-    if layer.bitwidth not in range(1, 5):
-        raise ValueError("Activation bitwidth must be an integer between 1 and "
-                         f"4. Receives bitwidth {layer.bitwidth} in layer "
-                         f"'{layer.name}'.")
+    if layer.bitwidth not in (1, 2, 4):
+        raise ValueError("Activation bitwidth must be in (1, 2, 4). Receives "
+                         f"bitwidth {layer.bitwidth} in layer '{layer.name}'.")
 
 
 def _check_concat_input_bitwidths(layer, concat_input_layers):
@@ -405,3 +405,12 @@ def _check_concat_input_bitwidths(layer, concat_input_layers):
             f"Concatenate layer '{layer.name}' must have inbound layers with "
             f"the same activation bitwidth. Receives bitwidths "
             f"{output_bitwidths}.")
+
+
+def _check_weight_bitwidth(bitwidth, layer_name):
+    """Checks that weight bitwidth is supported by Akida: 1, 2, 4 or 8 bits.
+    """
+
+    if bitwidth not in (1, 2, 4, 8):
+        raise ValueError("Weight bitwidth must be in (1, 2, 4, 8). Receives "
+                         f"bitwidth {bitwidth} in layer '{layer_name}'.")
