@@ -16,6 +16,7 @@
 """Model quantization API"""
 
 import warnings
+import tensorflow as tf
 from tensorflow.keras.models import clone_model
 from tensorflow.keras.layers import Conv2D, SeparableConv2D, Dense, ReLU, Layer
 
@@ -25,6 +26,7 @@ from .quantization_layers import (QuantizedConv2D, QuantizedSeparableConv2D,
                                   QuantizedActivation)
 from .utils import (invert_batchnorm_pooling, fold_batch_norms,
                     _find_batchnorms_to_fold)
+from .cnn2snn_objects import cnn2snn_objects
 
 keras_neural_layers = (Conv2D, SeparableConv2D, Dense)
 cnn2snn_neural_layers = (QuantizedConv2D, QuantizedSeparableConv2D,
@@ -117,7 +119,8 @@ def quantize(model,
                                                quantizer_function)
         return layer.__class__.from_config(layer.get_config())
 
-    new_model = clone_model(model_t, clone_function=replace_layer)
+    with tf.keras.utils.custom_object_scope(cnn2snn_objects):
+        new_model = clone_model(model_t, clone_function=replace_layer)
     new_model.set_weights(model_t.get_weights())
 
     return new_model
@@ -194,7 +197,8 @@ def quantize_layer(model, target_layer, bitwidth, quantizer_function=None):
             return layer.__class__.from_config(layer.get_config())
         return layer.__class__.from_config(layer.get_config())
 
-    new_model = clone_model(model, clone_function=replace_layer)
+    with tf.keras.utils.custom_object_scope(cnn2snn_objects):
+        new_model = clone_model(model, clone_function=replace_layer)
     new_model.set_weights(model.get_weights())
 
     return new_model
