@@ -189,7 +189,7 @@ class StdWeightQuantizer(LinearWeightQuantizer):
         return K.std(w) * self.threshold_
 
     def scale_factor(self, w):
-        return self.kmax_ / self.sigma_scaled_(w)
+        return clip_scale_factor(self.kmax_ / self.sigma_scaled_(w))
 
     def get_config(self):
         config = super().get_config()
@@ -241,7 +241,7 @@ class TrainableStdWeightQuantizer(LinearWeightQuantizer):
         return tf.math.reduce_std(w) * self.threshold_
 
     def scale_factor(self, w):
-        return self.kmax_ / self.sigma_scaled_(w)
+        return clip_scale_factor(self.kmax_ / self.sigma_scaled_(w))
 
     def get_config(self):
         config = super().get_config()
@@ -283,7 +283,7 @@ class MaxQuantizer(LinearWeightQuantizer):
         return tf.math.reduce_max(tf.math.abs(w))
 
     def scale_factor(self, w):
-        return self.kmax_ / self.max_range_(w)
+        return clip_scale_factor(self.kmax_ / self.max_range_(w))
 
 
 class MaxPerAxisQuantizer(MaxQuantizer):
@@ -313,9 +313,7 @@ class MaxPerAxisQuantizer(MaxQuantizer):
 
     def max_range_(self, w):
         red_range = tf.range(tf.rank(w) - 1)
-        low_limit_range = 1e-10
-        return tf.clip_by_value(tf.math.reduce_max(tf.math.abs(w), red_range),
-                                low_limit_range, tf.float32.max)
+        return tf.math.reduce_max(tf.math.abs(w), red_range)
 
 
 class ScaleFactorQuantizer(LinearWeightQuantizer):
@@ -342,7 +340,7 @@ class ScaleFactorQuantizer(LinearWeightQuantizer):
         super().__init__(bitwidth, **kwargs)
 
     def scale_factor(self, w):
-        return self.scale_factors
+        return clip_scale_factor(self.scale_factors)
 
     def get_config(self):
         config = super().get_config()
@@ -397,3 +395,10 @@ def ceil_through(x):
     """
     ceiling_value = tf.math.ceil(x)
     return x + K.stop_gradient(ceiling_value - x)
+
+
+def clip_scale_factor(scale_factor):
+    """ Clips scale factor(s) to 1000, in order to avoid very large scale
+    factors and thus very large Akida thresholds after conversion.
+    """
+    return tf.clip_by_value(scale_factor, 0, 1e3)
